/**
 * Author: Andrei Heidelbacher
 * Task: Network
 * Time complexity: O(V + E)
 * Space complexity: O(V + E)
 * Expected score: 20 points
 */

#include <cmath>

#include <fstream>
#include <iomanip>
#include <vector>
#include <algorithm>

using namespace std;

const char IN_FILE[] = "network.in";
const char OUT_FILE[] = "network.out";
const double EPS = 1e-7;

class Edge {
 public:
  int v;
  double p[2];

  Edge(const int _v, const double _p[2]):
   v(_v) {
       p[0] = _p[0];
       p[1] = _p[1];
   }

  Edge(const int _v, const double _p0, const double _p1):
      v(_v) {
          p[0] = _p0;
          p[1] = _p1;
    }
};

typedef vector<vector<Edge>> Graph;
typedef vector<Edge>::const_iterator EdgeIt;

inline int var(const int v, const int bit) {
  return (v << 1) ^ bit;
}

void dfs(
    const Graph &graph,
    const int x,
    vector<bool> &visited,
    vector<double> &dp) {
  visited[x] = true;
  dp[var(x, 0)] = dp[var(x, 1)] = 0;
  for (EdgeIt e = graph[x].begin(); e != graph[x].end(); ++e) {
    const int y = e->v;
    const double p[2] = {e->p[0], e->p[1]};
    if (!visited[y])
      dfs(graph, y, visited, dp);
    for (int bit = 0; bit <= 1; ++bit) {
      dp[var(x, bit)] += dp[var(y, bit)] * p[bit];
      dp[var(x, bit)] += (1 - p[bit]) * (1 - dp[var(y, bit ^ 1)]);
    }
  }
  dp[var(x, 0)] /= int(graph[x].size());
  dp[var(x, 1)] /= int(graph[x].size());
}

pair<double, double> solve(
    const Graph &graph,
    const int source,
    const int sink) {
  int v = int(graph.size());
  vector<bool> visited = vector<bool>(v, false);
  vector<double> sol = vector<double>(2 * v, 0);
  visited[sink] = true;
  sol[var(sink, 0)] = sol[var(sink, 1)] = 1;
  dfs(graph, source, visited, sol);
  return make_pair(sol[var(source, 0)], sol[var(source, 1)]);
}

Graph read() {
  ifstream in(IN_FILE);
  int v, e;
  in >> v >> e;
  Graph graph = Graph(v);
  for (int i = 0; i < e; ++i) {
    int from, to;
    double p0, p1;
    in >> from >> to >> p0 >> p1;
    graph[from].push_back(Edge(to, p0, p1));
  }
  in.close();
  return graph;
}

void write(const double p0, const double p1) {
  ofstream out(OUT_FILE);
  out << fixed << setprecision(7) << p0 << "\n" << p1 << "\n";
  out.close();
}

int main() {
  const Graph graph = read();
  pair<double, double> p = solve(graph, 0, int(graph.size()) - 1);
  write(p.first, p.second);
  return 0;
}
