#include <cstdio>
#include <cstdlib>
#include <vector>
#include <map>
#include <algorithm>
using namespace std;

const int nmax = 5010, ctcmax = 80;
const long double EPS = 1e-9;

int n, m, N, M, topsort[nmax], which[nmax], whichComp;
bool used[nmax];

struct Edge
{
	int other;
	double p0, p1;

	Edge(int _other, double _p0, double _p1)
	{
		other = _other;
		p0 = _p0;
		p1 = _p1;
	}
};

vector<Edge> g[nmax], gt[nmax];
vector<int> crtCTC, ctcGraph[nmax];
vector<vector<int> > comps;
long double dp[nmax][2];
long double A[2 * ctcmax][2 * ctcmax], sol[2 * ctcmax];

void DoGauss()
{
    int Ec = 1, Nec = 1;
    while(Ec <= N && Nec <= M)
    {
        int i;
        for(i = Ec; i <= N; ++ i)
            if(fabs(A[i][Nec]) > EPS)
                break;
 
        if(i == N + 1)
        {
            Nec ++;
            continue;
        }
 
        for(int k = 1; k <= M + 1; ++ k)
            swap(A[i][k], A[Ec][k]);
 
        for(int i = 1; i <= N; ++ i)
            if(i != Ec)
            {
                long double R = A[i][Nec] / A[Ec][Nec];
                for(int j = Nec; j <= M + 1; ++ j)
                    A[i][j] -= A[Ec][j] * R;
            }
 
        Ec ++;
        Nec ++;
    }
 
    for(int i = 1; i <= N; ++ i)
    	sol[i] = A[i][M + 1] / A[i][i];
}

map<int, int> indexNode;

void solveCTC(vector<int> nodes)
{
	indexNode.clear();
	N = M = 2 * int(nodes.size());
	for (int i = 0; i < nodes.size(); ++ i)
		indexNode[nodes[i]] = i;

	for (int i = 1; i <= N; ++ i)
		for (int j = 1; j <= M + 1; ++ j)
			A[i][j] = 0.0;

	for (int i = 0; i < nodes.size(); ++ i)
	{
		int node = nodes[i];
		for (int j = 0; j < g[node].size(); ++ j)
		{
			int vec = g[node][j].other;
			long double p0 = g[node][j].p0;
			long double p1 = g[node][j].p1;

			if (which[node] == which[vec])
			{
				int indNode = indexNode[node];
				vec = indexNode[vec];
				A[2 * indNode + 1][2 * vec + 1] = -p0;
				A[2 * indNode + 1][2 * vec + 2] = 1.0 - p0;
				A[2 * indNode + 2][2 * vec + 1] = 1.0 - p1;
				A[2 * indNode + 2][2 * vec + 2] = -p1;
				A[2 * indNode + 1][M + 1] += 1.0 - p0;
				A[2 * indNode + 2][M + 1] += 1.0 - p1;
			}else 
			{
				int indNode = indexNode[node];
				A[2 * indNode + 1][M + 1] += 1.0 * p0 * dp[vec][0] + (1.0 - p0) * (1.0 - dp[vec][1]);
				A[2 * indNode + 2][M + 1] += 1.0 * p1 * dp[vec][1] + (1.0 - p1) * (1.0 - dp[vec][0]);
			}
		}
	}

	for (int i = 0; i < nodes.size(); ++ i)
	{
		if (g[nodes[i]].size() == 0) continue;

		for (int j = 1; j <= M + 1; ++ j)
		{
			A[2 * i + 1][j] /= 1.0 * g[nodes[i]].size();
			A[2 * i + 2][j] /= 1.0 * g[nodes[i]].size();
		}
		A[2 * i + 1][2 * i + 1] = 1.0;
		A[2 * i + 2][2 * i + 2] = 1.0;
	}

	for (int i = 0; i < nodes.size(); ++ i)
		if (nodes[i] == n)
		{
			A[2 * i + 1][2 * i + 1] = A[2 * i + 1][M + 1] = 1.0;
			A[2 * i + 2][2 * i + 2] = A[2 * i + 2][M + 1] = 1.0;
		}

	DoGauss();

	for (int i = 0; i < nodes.size(); ++ i)
		dp[nodes[i]][0] = sol[2 * i + 1], dp[nodes[i]][1] = sol[2 * i + 2];
}

void dfp(int node)
{
	used[node] = 1;
	for (int i = 0; i < g[node].size(); ++ i)
	{
		int vec = g[node][i].other;
		if (!used[vec])
			dfp(vec);
	}
	topsort[++topsort[0]] = node;
}

void dfm(int node)
{
	used[node] = 0;
	crtCTC.push_back(node);
	which[node] = whichComp;

	for (int i = 0; i < gt[node].size(); ++ i)
	{
		int vec = gt[node][i].other;
		if (used[vec])
			dfm(vec);
	}
}

int main()
{
	freopen("network.in", "r", stdin);
	freopen("network.out", "w", stdout);

	scanf("%i %i", &n, &m);
	for (int i = 1; i <= m; ++ i)
	{
		int x, y;
		double p0, p1;
		scanf("%d %d %lf %lf", &x, &y, &p0, &p1);
		x ++;
		y ++;
		g[x].push_back(Edge(y, p0, p1));
		gt[y].push_back(Edge(x, p0, p1));
	}

	for (int i = 1; i <= n; ++ i)
		if (!used[i])
			dfp(i);
	for (int i = topsort[0]; i; -- i)
		if (used[topsort[i]])
		{
			crtCTC.clear();
			whichComp ++;
			dfm(topsort[i]);
			comps.push_back(crtCTC);
		}

	for (int i = comps.size() - 1; i >= 0; -- i)
		solveCTC(comps[i]);

	printf("%.10Lf %.10Lf\n", dp[1][0], dp[1][1]);
}